﻿using Syncfusion.Windows.Shared;
using Syncfusion.Windows.Tools.Controls;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using TreeViewAdv_WPF.Model;
using Directory = TreeViewAdv_WPF.Model.Directory;

namespace TreeViewAdv_WPF
{
    public class ViewModel : NotificationObject
    {

        public ViewModel()
        {
            _items = new ObservableCollection<IItem>();
            
            // Load Initial Root Folders
            DriveInfo[] drives = DriveInfo.GetDrives();
            int count = 0;

            foreach (DriveInfo info in drives)
            {
                Directory directory = new Directory();
                directory.Name = "Local Disk " + info.Name;
                directory.Info = info;
                if (count == 0)
                {
                    directory.IsSelected = true;
                }
                TreeItems.Add(directory);
                count++;
            }



            MouseDownClick = new DelegateCommand<object>(MouseDownClicked);
        }

        private ObservableCollection<IItem> _items;
        public ObservableCollection<IItem> TreeItems
        {
            get => _items;
            set
            {
                _items = value;
                this.RaisePropertyChanged(() => this.TreeItems);
            }
        }


        private void BuildDirectoryTree(TreeViewItemAdv item,IItem file)
        {
            var path = "";

            if (item!=null && file != null)
            {
                if (file.Info is DriveInfo)
                {
                    path = ((DriveInfo)file.Info).Name;
                }
                else if (file.Info is DirectoryInfo)
                {
                    path = ((DirectoryInfo)file.Info).FullName;
                }

                if (String.IsNullOrEmpty(path))
                {
                    return;
                }
                DirectoryInfo info = new DirectoryInfo(path);
                if (info.Exists)
                {
                    try
                    {
                        var infos = info.GetDirectories().OrderBy(x => x.Name);
                        foreach (DirectoryInfo directory in infos)
                        {
                            // ignore Recycle Bin
                            if (directory.Name.ToLower().Equals("$recycle.bin") || directory.Name.Equals("Config.Msi") || directory.Name.Equals("System Volume Information"))
                            {
                                continue;
                            }
                            Directory _file = new Directory();
                            _file.Name = directory.Name;
                            _file.Info = directory;
                            ((Directory)file).Files.Add(_file);
                            ((Directory)file).Items.Add(_file);
                        }
                    }
                    catch (Exception e)
                    {
                        //MessageBox.Show(e.Message);
                    }
                }
                else
                {
                    //MessageBox.Show("The Device is not ready.", "Disk Error", MessageBoxButton.OK, MessageBoxImage.Error);
                }               
                item.IsLoadOnDemand = false;
            }
        }
        

        private ICommand mouseDownClick;
        public ICommand MouseDownClick
        {
            get { return mouseDownClick; }
            set { mouseDownClick = value; }
        }

        private void MouseDownClicked(object model)
        {
            //Perform your actions.
           TreeViewItemAdv treeitem = (model as LoadonDemandEventArgs).TreeViewItem;
            if (treeitem != null)
            {
                BuildDirectoryTree(treeitem, treeitem.DataContext as IItem);
            }
        }

       

    }
}


